@@ -78,7 +78,7 @@ void show_status (void)
     unsigned long cnt = 0;
 
     int s = 0;
-    l2tp_log (LOG_WARNING, "====== l2tpd statistics ========\n");
+    l2tp_log (LOG_WARNING, "====== xl2tpd statistics ========\n");
     l2tp_log (LOG_WARNING, " Scheduler entries:\n");
     se = events;
     while (se)
@@ -846,6 +846,9 @@ void do_control ()
     char *tunstr;
     char *callstr;
 
+    char *authname = NULL;
+    char *password = NULL;
+    char delims[] = " ";
     char *sub_str;              /* jz: use by the strtok function */
     char *tmp_ptr;              /* jz: use by the strtok function */
     struct lac *lac;
@@ -887,7 +890,10 @@ void do_control ()
         case 'c':
             switch_io = 1;  /* jz: Switch for Incoming - Outgoing Calls */
             
-            tunstr = strchr (buf, ' ') + 1;
+            tunstr = strtok (&buf[1], delims);
+            authname = strtok (NULL, delims);
+            password = strtok (NULL, delims);
+
             lac = laclist;
             while (lac && strcasecmp (lac->entname, tunstr)!=0)
             {
@@ -897,6 +903,10 @@ void do_control ()
             if(lac) {
                 lac->active = -1;
                 lac->rtries = 0;
+                if (authname != NULL)
+                    strncpy (lac->authname, authname, STRLEN);
+                if (password != NULL)
+                    strncpy (lac->password, password, STRLEN);
                 if (!lac->c)
                 magic_lac_dial (lac);
                 else {
@@ -1018,7 +1028,7 @@ void do_control ()
 
 void usage(void) {
     printf("\nxl2tpd version:  %s\n",SERVER_VERSION);
-    printf("Usage: l2tpd [-c <config file>] [-s <secret file>] [-p <pid file>]  \n             [-C <control file>] [-D]\n");
+    printf("Usage: xl2tpd [-c <config file>] [-s <secret file>] [-p <pid file>]  \n             [-C <control file>] [-D]\n");
     printf("\n");
     exit(1);
 }
@@ -1143,7 +1153,8 @@ void consider_pidfile() {
            complain and exit immediately. */
         if (pid && pid != getpid () && kill (pid, 0) == 0)
         {
-            l2tp_log(LOG_INFO, "%s: There's already a l2tpd server running.\n",
+            l2tp_log(LOG_INFO,
+                    "%s: There's already a xl2tpd server running.\n",
                     __FUNCTION__);
             close(server_socket);
             exit(1);
